Method: Microstation::Drawing#pdf_name

Defined in:
lib/microstation/drawing.rb

#pdf_name(name = nil) ⇒ Object

Return the pdf name for the drawing.

If a name is provided use the name provided otherwise use the drawing name

Parameters:

  • name (String, nil) (defaults to: nil)

    @return a Pathname from the name or drawing name



281
282
283
284
# File 'lib/microstation/drawing.rb', line 281

def pdf_name(name = nil)
  name ||= self.name
  Pathname(name).sub_ext(".pdf")
end